==> chromium-browser_34.0.1847.116.orig.tar.xz: chromium-34.0.1847.116/remoting/base/test_rsa_key_pair.h <==
// Copyright (c) 2010 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

namespace remoting {

// An RSA keypair used in unittests.
const char kTestRsaKeyPair[] =
"MIIEvgIBADANBgkqhkiG9w0BAQEFAASCBKgwggSkAgEAAoIBAQDeeT/wgtzQkGoeA5LRQI4iXibQZ"
"R3YUiJn/oVz0P+KLJSCWL4Uhjl3CytKg0nzuxgaJ9UOHxrl91k1XnLnwJytqkjl8kgWle+JJbiDx3"
"+3WBxmSjPWmmaPNuBebpyTD1N3TJEPRwe7vfYiOz56jzBPSm3gqIeRvJGIC+Ou+Q0OV+ISTu2Jjtj"
"MP3NOLfXjoZfoovPkZAB3/cjwjlBbd+0XWz+b3cAe5zfzcZkDvw6L4htwl/+MlRk7XX1U2dEoaI+x"
"/kZkigfJdfw7k5RCTmygp1A94rUXBaR5m7p+5eVChTXYjqmh0PrEwVr88D/F58zByma5ZNGFyyj1u"
"nXTNUUZAgMBAAECggEAKFvUppwG1Ost5Q3+52kPn9p2rh154ZFc3oLE0PLcOMPHmTHiIbUL3bWv/8"
"97bfTF9ZC+TNaFuaw6ibz9mV9OzQ50NQrT2w0OLFIke/uIBsm8NS5G4yqVamupHlhwnRkNqjnAowX"
"euEdIzIL03aT2PZwh/Lx2A5Ey0XxerJJPtQcTp1UTSdRafAN+gSvS25DbLUUoAhG4J3auaeD3rg/2"
"REeCeqaRrHbD33kB8Sw/u/dZ6sKE2IKeFIzNZBzihYa62Q1YWcFfYpPe9b+9CFM85kKgRUZMJtxQl"
"aSDpi5eK5+EvyQdCQY/eRvhZLOuqD5EBiNZiYUfcWDk582WkFUX9QKBgQD85odRTpZRW6T5adok7I"
"TexReoUGxqSIyPQfAbdTVXP+yRr0a8WLZSL3wYh7i4qR5B7Rg2K7XZxj/RWzI5cTicvJ7MaD7/N1n"
"X25bPQwgZKXSVJ0vfde4MHzu7w8cltjWz7crO/7qy6kyOi13jI43fixMhoALJHZJIN7A8m10MxwKB"
"gQDhM0HhSYNSI5UEavELyKEyXTj4b6XNJ2SGFsM1gHDJeKarSzPkxEPhxt5S8Hfr5e2wmXl27gd6u"
"52pizriA/H98dvneeXvcYETLbysBKFnWdaJ6P4d45MTEVWnNTWFpbnDMH2GaqJ9WpwxOYrh4QM1nm"
"4Q/kfkpwDzrQpHu5Z/HwKBgQCbpwcB8+xwhoczOwMYVrowof29ikIv6Bca1OqC+9Cosp9XyxkuMyu"
"DydYHAwGeJfiJevO744s5TdtZb1eqIxVE4pKaHE8ppVeWk4BucEM7uVgXtOft0ReCPnb1Sbn4a/0B"
"kQmR/bNbCvmzgfN3KRrYyzArMeCFB75Q1HWT18udYQKBgQCFX7Qe10j9NrGk4ilMj1BY4blB+e26a"
"SAyAf0vDJi/2cLsJCfhzxNc/kjh2iVMAusY8mxrsWGgoMkphpojDa8edUWF/D3f59tIHohlYICvEx"
"fqqaEG1qdeXZ/a3bqLIrG4FlnhZ/pAP4/N34SPbpJWCTSqv86YbwgzSUKTZVgmhQKBgAZbvdZM8x8"
"Et5ho7YqrrBWTwnvMLw4G7qftiMco15JcMAXhfGhmlDI8OUq7MlXVCUWwdZtRYcAyWJcqhWQ3yrXv"
"8cWi9hxwNGPuof5PchDDuR+cwe8gZvpzwfFDFTgJHIBe64CkFd9Oeb5CvEffbrP04mpWvjVeMcjjz"
"ZA6a+IB";

}  // namespace remoting

==> chromium-browser_71.0.3578.80.orig.tar.xz: chromium-71.0.3578.80/remoting/base/test_rsa_key_pair.h <==
// Copyright (c) 2010 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef REMOTING_BASE_TEST_RSA_KEY_PAIR_H_
#define REMOTING_BASE_TEST_RSA_KEY_PAIR_H_

namespace remoting {

// An RSA keypair used in unittests.
const char kTestRsaKeyPair[] =
"MIIEvgIBADANBgkqhkiG9w0BAQEFAASCBKgwggSkAgEAAoIBAQDeeT/wgtzQkGoeA5LRQI4iXibQZ"
"R3YUiJn/oVz0P+KLJSCWL4Uhjl3CytKg0nzuxgaJ9UOHxrl91k1XnLnwJytqkjl8kgWle+JJbiDx3"
"+3WBxmSjPWmmaPNuBebpyTD1N3TJEPRwe7vfYiOz56jzBPSm3gqIeRvJGIC+Ou+Q0OV+ISTu2Jjtj"
"MP3NOLfXjoZfoovPkZAB3/cjwjlBbd+0XWz+b3cAe5zfzcZkDvw6L4htwl/+MlRk7XX1U2dEoaI+x"
"/kZkigfJdfw7k5RCTmygp1A94rUXBaR5m7p+5eVChTXYjqmh0PrEwVr88D/F58zByma5ZNGFyyj1u"
"nXTNUUZAgMBAAECggEAKFvUppwG1Ost5Q3+52kPn9p2rh154ZFc3oLE0PLcOMPHmTHiIbUL3bWv/8"
"97bfTF9ZC+TNaFuaw6ibz9mV9OzQ50NQrT2w0OLFIke/uIBsm8NS5G4yqVamupHlhwnRkNqjnAowX"
"euEdIzIL03aT2PZwh/Lx2A5Ey0XxerJJPtQcTp1UTSdRafAN+gSvS25DbLUUoAhG4J3auaeD3rg/2"
"REeCeqaRrHbD33kB8Sw/u/dZ6sKE2IKeFIzNZBzihYa62Q1YWcFfYpPe9b+9CFM85kKgRUZMJtxQl"
"aSDpi5eK5+EvyQdCQY/eRvhZLOuqD5EBiNZiYUfcWDk582WkFUX9QKBgQD85odRTpZRW6T5adok7I"
"TexReoUGxqSIyPQfAbdTVXP+yRr0a8WLZSL3wYh7i4qR5B7Rg2K7XZxj/RWzI5cTicvJ7MaD7/N1n"
"X25bPQwgZKXSVJ0vfde4MHzu7w8cltjWz7crO/7qy6kyOi13jI43fixMhoALJHZJIN7A8m10MxwKB"
"gQDhM0HhSYNSI5UEavELyKEyXTj4b6XNJ2SGFsM1gHDJeKarSzPkxEPhxt5S8Hfr5e2wmXl27gd6u"
"52pizriA/H98dvneeXvcYETLbysBKFnWdaJ6P4d45MTEVWnNTWFpbnDMH2GaqJ9WpwxOYrh4QM1nm"
"4Q/kfkpwDzrQpHu5Z/HwKBgQCbpwcB8+xwhoczOwMYVrowof29ikIv6Bca1OqC+9Cosp9XyxkuMyu"
"DydYHAwGeJfiJevO744s5TdtZb1eqIxVE4pKaHE8ppVeWk4BucEM7uVgXtOft0ReCPnb1Sbn4a/0B"
"kQmR/bNbCvmzgfN3KRrYyzArMeCFB75Q1HWT18udYQKBgQCFX7Qe10j9NrGk4ilMj1BY4blB+e26a"
"SAyAf0vDJi/2cLsJCfhzxNc/kjh2iVMAusY8mxrsWGgoMkphpojDa8edUWF/D3f59tIHohlYICvEx"
"fqqaEG1qdeXZ/a3bqLIrG4FlnhZ/pAP4/N34SPbpJWCTSqv86YbwgzSUKTZVgmhQKBgAZbvdZM8x8"
"Et5ho7YqrrBWTwnvMLw4G7qftiMco15JcMAXhfGhmlDI8OUq7MlXVCUWwdZtRYcAyWJcqhWQ3yrXv"
"8cWi9hxwNGPuof5PchDDuR+cwe8gZvpzwfFDFTgJHIBe64CkFd9Oeb5CvEffbrP04mpWvjVeMcjjz"
"ZA6a+IB";

}  // namespace remoting

#endif  // REMOTING_BASE_TEST_RSA_KEY_PAIR_H_
